@@ -1,16 +1,18 @@
+# frozen_string_literal: true
+
 require "helper"
 
 class TestMemoryLeak < Nokogiri::TestCase
   def setup
     super
-    @str = <<EOF
-<!DOCTYPE HTML>
-<html>
-  <body>
-    <br />
-  </body>
-</html>
-EOF
+    @str = <<~EOF
+      <!DOCTYPE HTML>
+      <html>
+        <body>
+          <br />
+        </body>
+      </html>
+    EOF
   end
 
   #
@@ -29,46 +31,45 @@ EOF
   #  which is an open issue to resurrect these tests and run them as
   #  part of the CI pipeline.
   #
-  if ENV['NOKOGIRI_GC'] # turning these off by default for now
+  if ENV["NOKOGIRI_GC"] # turning these off by default for now
     def test_dont_hurt_em_why
-      content = File.open("#{File.dirname(__FILE__)}/files/dont_hurt_em_why.xml").read
+      content = File.read("#{File.dirname(__FILE__)}/files/dont_hurt_em_why.xml")
       ndoc = Nokogiri::XML(content)
       2.times do
-        ndoc.search('status text').first.inner_text
-        ndoc.search('user name').first.inner_text
+        ndoc.search("status text").first.inner_text
+        ndoc.search("user name").first.inner_text
         GC.start
       end
     end
 
     class BadIO
       def read(*args)
-        raise 'hell'
+        raise "hell"
       end
 
       def write(*args)
-        raise 'chickens'
+        raise "chickens"
       end
     end
 
     def test_for_mem_leak_on_io_callbacks
-      io = File.open SNUGGLES_FILE
+      io = File.open(SNUGGLES_FILE)
       Nokogiri::XML.parse(io)
 
       loop do
-        Nokogiri::XML.parse(BadIO.new) rescue nil
-        doc.write BadIO.new rescue nil
+        Nokogiri::XML.parse(BadIO.new) rescue nil # rubocop:disable Style/RescueModifier
+        doc.write(BadIO.new) rescue nil # rubocop:disable Style/RescueModifier
       end
     end
 
     def test_for_memory_leak
-      begin
-        #  we don't use Dike in any tests, but requiring it has side effects
-        #  that can create memory leaks, and that's what we're testing for.
-        require 'rubygems'
-        require 'dike' # do not remove!
+      #  we don't use Dike in any tests, but requiring it has side effects
+      #  that can create memory leaks, and that's what we're testing for.
+      require "rubygems"
+      require "dike" # do not remove!
 
-        count_start = count_object_space_documents
-        xml_data = <<-EOS
+      count_start = count_object_space_documents
+      xml_data = <<-EOS
         <test>
           <items>
             <item>abc</item>
@@ -76,21 +77,20 @@ EOF
             <item>Zzz</item>
           <items>
         </test>
-        EOS
-        20.times do
-          doc = Nokogiri::XML(xml_data)
-          doc.xpath("//item")
-        end
-        2.times { GC.start }
-        count_end = count_object_space_documents
-        assert((count_end - count_start) <= 2, "memory leak detected")
-      rescue LoadError
-        puts "\ndike is not installed, skipping memory leak test"
+      EOS
+      20.times do
+        doc = Nokogiri::XML(xml_data)
+        doc.xpath("//item")
       end
+      2.times { GC.start }
+      count_end = count_object_space_documents
+      assert((count_end - count_start) <= 2, "memory leak detected")
+    rescue LoadError
+      puts "\ndike is not installed, skipping memory leak test"
     end
 
     def test_node_set_namespace_mem_leak
-      xml = Nokogiri::XML "<foo></foo>"
+      xml = Nokogiri::XML("<foo></foo>")
       ctx = Nokogiri::XML::XPathContext.new(xml)
       loop do
         ctx.evaluate("//namespace::*")
@@ -127,7 +127,7 @@ EOF
       end
 
       def start_element(name, attrs = [])
-        throw @jumptag
+        throw(@jumptag)
       end
     end
 
@@ -144,31 +144,31 @@ EOF
     def test_in_context_parser_leak
       loop do
         doc = Nokogiri::XML::Document.new
-        fragment1 = Nokogiri::XML::DocumentFragment.new(doc, '<foo/>')
+        fragment1 = Nokogiri::XML::DocumentFragment.new(doc, "<foo/>")
         node = fragment1.children[0]
-        node.parse('<bar></bar>')
+        node.parse("<bar></bar>")
       end
     end
 
     def test_in_context_parser_leak_ii
-      loop { Nokogiri::XML('<a/>').root.parse('<b/>') }
+      loop { Nokogiri::XML("<a/>").root.parse("<b/>") }
     end
 
     def test_leak_on_xpath_string_function
       doc = Nokogiri::XML(@str)
       loop do
-        doc.xpath('name(//node())')
+        doc.xpath("name(//node())")
       end
     end
 
     def test_leaking_namespace_node_strings
       # see https://github.com/sparklemotion/nokogiri/issues/1810 for memory leak report
-      ns = {'xmlns' => 'http://schemas.xmlsoap.org/soap/envelope/'}
+      ns = { "xmlns" => "http://schemas.xmlsoap.org/soap/envelope/" }
       20.times do
         10_000.times do
           Nokogiri::XML::Builder.new do |xml|
-            xml.send 'Envelope', ns do
-              xml.send 'Foobar', ns
+            xml.send("Envelope", ns) do
+              xml.send("Foobar", ns)
             end
           end
         end
@@ -178,12 +178,12 @@ EOF
 
     def test_leaking_namespace_node_strings_with_prefix
       # see https://github.com/sparklemotion/nokogiri/issues/1810 for memory leak report
-      ns = {'xmlns:foo' => 'http://schemas.xmlsoap.org/soap/envelope/'}
+      ns = { "xmlns:foo" => "http://schemas.xmlsoap.org/soap/envelope/" }
       20.times do
         10_000.times do
           Nokogiri::XML::Builder.new do |xml|
-            xml.send 'Envelope', ns do
-              xml.send 'Foobar', ns
+            xml.send("Envelope", ns) do
+              xml.send("Foobar", ns)
             end
           end
         end
@@ -196,7 +196,7 @@ EOF
       100_000.times do |i|
         doc = Nokogiri::HTML::Document.new
         doc.internal_subset.remove
-        puts MemInfo.rss if (i % 1000 == 0)
+        puts MemInfo.rss if i % 1000 == 0
       end
     end
 
@@ -205,13 +205,12 @@ EOF
         prev_rss = MemInfo.rss
         100_001.times do |j|
           Nokogiri::XML::RelaxNG.from_document(Nokogiri::XML::Document.parse(File.read(ADDRESS_SCHEMA_FILE)))
-          if (j % 10_000 == 0)
-            curr_rss = MemInfo.rss
-            diff_rss = curr_rss - prev_rss
-            printf("\n(iter %d) %d", j, curr_rss)
-            printf(" (%s%d)", diff_rss >= 0 ? "+" : "-", diff_rss) if j > 0
-            prev_rss = curr_rss
-          end
+          next unless j % 10_000 == 0
+          curr_rss = MemInfo.rss
+          diff_rss = curr_rss - prev_rss
+          printf("\n(iter %d) %d", j, curr_rss)
+          printf(" (%s%d)", diff_rss >= 0 ? "+" : "-", diff_rss) if j > 0
+          prev_rss = curr_rss
         end
         puts
       end
@@ -221,15 +220,19 @@ EOF
   module MemInfo
     # from https://stackoverflow.com/questions/7220896/get-current-ruby-process-memory-usage
     # this is only going to work on linux
-    PAGE_SIZE = `getconf PAGESIZE`.chomp.to_i rescue 4096
+    PAGE_SIZE = begin
+      %x(getconf PAGESIZE).chomp.to_i
+    rescue
+      4096
+    end
     STATM_PATH = "/proc/#{Process.pid}/statm"
     STATM_FOUND = File.exist?(STATM_PATH)
 
     def self.rss
       if STATM_FOUND
-        return (File.read(STATM_PATH).split(' ')[1].to_i * PAGE_SIZE) / 1024
+        return (File.read(STATM_PATH).split(" ")[1].to_i * PAGE_SIZE) / 1024
       end
-      return 0
+      0
     end
   end
 
@@ -237,7 +240,7 @@ EOF
 
   def count_object_space_documents
     count = 0
-    ObjectSpace.each_object {|j| count += 1 if j.is_a?(Nokogiri::XML::Document) }
+    ObjectSpace.each_object { |j| count += 1 if j.is_a?(Nokogiri::XML::Document) }
     count
   end
 end
