@@ -1,4 +1,5 @@
 # frozen_string_literal: true
+
 require "helper"
 
 module Nokogiri
@@ -11,26 +12,26 @@ module Nokogiri
           html = "foo"
           doc = Nokogiri::XML::DocumentFragment.parse(html)
           doc.children[0].replace("bar")
-          assert_equal('bar', doc.children[0].content)
+          assert_equal("bar", doc.children[0].content)
         end
 
         def test_fragment_is_relative
           doc      = Nokogiri::XML('<root><a xmlns="blah" /></root>')
           ctx      = doc.root.child
-          fragment = Nokogiri::XML::DocumentFragment.new(doc, '<hello />', ctx)
+          fragment = Nokogiri::XML::DocumentFragment.new(doc, "<hello />", ctx)
           hello    = fragment.child
 
-          assert_equal('hello', hello.name)
+          assert_equal("hello", hello.name)
           assert_equal(doc.root.child.namespace, hello.namespace)
         end
 
         def test_node_fragment_is_relative
           doc = Nokogiri::XML('<root><a xmlns="blah" /></root>')
           assert(doc.root.child)
-          fragment = doc.root.child.fragment('<hello />')
+          fragment = doc.root.child.fragment("<hello />")
           hello    = fragment.child
 
-          assert_equal('hello', hello.name)
+          assert_equal("hello", hello.name)
           assert_equal(doc.root.child.namespace, hello.namespace)
         end
 
@@ -45,7 +46,7 @@ module Nokogiri
 
         def test_name
           fragment = Nokogiri::XML::DocumentFragment.new(xml)
-          assert_equal('#document-fragment', fragment.name)
+          assert_equal("#document-fragment", fragment.name)
         end
 
         def test_static_method
@@ -112,12 +113,12 @@ module Nokogiri
           fragment = Nokogiri::XML::Document.new.fragment(
             '<div><p id="content">hi</p></div>'
           )
-          expected = fragment.children.xpath('.//p')
+          expected = fragment.children.xpath(".//p")
           assert_equal(1, expected.length)
 
-          css          = fragment.children.css('p')
-          search_css   = fragment.children.search('p')
-          search_xpath = fragment.children.search('.//p')
+          css          = fragment.children.css("p")
+          search_css   = fragment.children.search("p")
+          search_xpath = fragment.children.search(".//p")
           assert_equal(expected, css)
           assert_equal(expected, search_css)
           assert_equal(expected, search_xpath)
@@ -130,14 +131,14 @@ module Nokogiri
           fragment = Nokogiri::XML::DocumentFragment.parse(<<~EOXML)
             <p id="content">hi</p> x <!--y--> <p>another paragraph</p>
           EOXML
-          children = fragment.css('p')
+          children = fragment.css("p")
           assert_equal(2, children.length)
           # removing the last node instead does not yield the error. Probably the
           # node removal leaves around two consecutive text nodes which make the
           # css search crash?
           children.first.remove
-          assert_equal(1, fragment.xpath('.//p | self::p').length)
-          assert_equal(1, fragment.css('p').length)
+          assert_equal(1, fragment.xpath(".//p | self::p").length)
+          assert_equal(1, fragment.css("p").length)
         end
 
         def test_fragment_search_three_ways
@@ -146,32 +147,53 @@ module Nokogiri
           assert_equal(2, expected.length)
 
           [
-            [:css, '#content'],
-            [:search, '#content'],
-            [:search, './*[@id = \'content\']'],
+            [:css, "#content"],
+            [:search, "#content"],
+            [:search, "./*[@id = 'content']"],
           ].each do |method, query|
             result = frag.send(method, query)
             assert_equal(expected, result,
-                         "fragment search with :#{method} using '#{query}' expected '#{expected}' got '#{result}'")
+              "fragment search with :#{method} using '#{query}' expected '#{expected}' got '#{result}'")
           end
         end
 
+        def test_search_direct_children_of_fragment
+          xml = <<~XML
+            <div class="section header" id="1">
+              <div class="subsection header">sub 1</div>
+              <div class="subsection header">sub 2</div>
+            </div>
+            <div class="section header" id="2">
+              <div class="subsection header">sub 3</div>
+              <div class="subsection header">sub 4</div>
+            </div>
+          XML
+          fragment = Nokogiri::XML.fragment(xml)
+          result = (fragment > "div.header")
+          assert_equal(2, result.length)
+          assert_equal(["1", "2"], result.map { |n| n["id"] })
+
+          assert_empty(fragment > ".no-such-match")
+        end
+
         def test_fragment_search_with_multiple_queries
-          xml = '<thing>
-                 <div class="title">important thing</div>
-               </thing>
-               <thing>
-                 <div class="content">stuff</div>
-               </thing>
-               <thing>
-                 <p class="blah">more stuff</div>
-               </thing>'
+          xml = <<~EOF
+            <thing>
+              <div class="title">important thing</div>
+            </thing>
+            <thing>
+              <div class="content">stuff</div>
+            </thing>
+            <thing>
+              <p class="blah">more stuff</div>
+            </thing>
+          EOF
           fragment = Nokogiri::XML.fragment(xml)
           assert_kind_of(Nokogiri::XML::DocumentFragment, fragment)
 
-          assert_equal(3, fragment.xpath('.//div', './/p').length)
-          assert_equal(3, fragment.css('.title', '.content', 'p').length)
-          assert_equal(3, fragment.search('.//div', 'p.blah').length)
+          assert_equal(3, fragment.xpath(".//div", ".//p").length)
+          assert_equal(3, fragment.css(".title", ".content", "p").length)
+          assert_equal(3, fragment.search(".//div", "p.blah").length)
         end
 
         def test_fragment_without_a_namespace_does_not_get_a_namespace
@@ -215,12 +237,12 @@ module Nokogiri
           util_decorate(xml, x)
           fragment = Nokogiri::XML::DocumentFragment.new(xml, "<div>a</div><div>b</div>")
 
-          assert(node_set = fragment.css('div'))
-          assert(node_set.respond_to?(:awesome!))
+          assert(node_set = fragment.css("div"))
+          assert_respond_to(node_set, :awesome!)
           node_set.each do |node|
-            assert(node.respond_to?(:awesome!), node.class)
+            assert_respond_to(node, :awesome!, node.class)
           end
-          assert(fragment.children.respond_to?(:awesome!), fragment.children.class)
+          assert_respond_to(fragment.children, :awesome!, fragment.children.class)
         end
 
         def test_decorator_is_applied_to_empty_set
@@ -230,12 +252,12 @@ module Nokogiri
           end
           util_decorate(xml, x)
           fragment = Nokogiri::XML::DocumentFragment.new(xml, "")
-          assert(fragment.children.respond_to?(:awesome!), fragment.children.class)
+          assert_respond_to(fragment.children, :awesome!, fragment.children.class)
         end
 
         def test_add_node_to_doc_fragment_segfault
-          frag = Nokogiri::XML::DocumentFragment.new(xml, '<p>hello world</p>')
-          Nokogiri::XML::Comment.new(frag, 'moo')
+          frag = Nokogiri::XML::DocumentFragment.new(xml, "<p>hello world</p>")
+          Nokogiri::XML::Comment.new(frag, "moo")
         end
 
         def test_issue_1077_parsing_of_frozen_strings
@@ -255,7 +277,7 @@ module Nokogiri
           # https://github.com/sparklemotion/nokogiri/issues/1063
           original = Nokogiri::XML::DocumentFragment.parse("<div><p>hello</p></div>")
           duplicate = original.dup
-          assert_not_equal(original.document, duplicate.document)
+          refute_equal(original.document, duplicate.document)
         end
 
         def test_dup_should_create_an_xml_document_fragment
@@ -276,7 +298,7 @@ module Nokogiri
           duplicate = original.dup
           duplicate.at_css("div").add_child("<b>hello there</b>")
           assert_nil(original.at_css("b"))
-          assert_not_nil(duplicate.at_css("b"))
+          refute_nil(duplicate.at_css("b"))
         end
 
         def test_for_libxml_in_context_fragment_parsing_bug_workaround
@@ -310,6 +332,147 @@ module Nokogiri
           end
         end
 
+        describe "parse options" do
+          let(:xml_default) do
+            Nokogiri::XML::ParseOptions.new(Nokogiri::XML::ParseOptions::DEFAULT_XML)
+          end
+
+          let(:xml_strict) do
+            Nokogiri::XML::ParseOptions.new(Nokogiri::XML::ParseOptions::DEFAULT_XML).norecover
+          end
+
+          let(:input) { "<a>foo</a" }
+
+          it "sets the test up correctly" do
+            assert(xml_strict.strict?)
+          end
+
+          describe "XML.fragment" do
+            it "has sane defaults" do
+              frag = Nokogiri::XML.fragment(input)
+              assert_equal("<a>foo</a>", frag.to_html)
+              refute_empty(frag.errors)
+            end
+
+            it "accepts options" do
+              frag = Nokogiri::XML.fragment(input, xml_default)
+              assert_equal("<a>foo</a>", frag.to_html)
+              refute_empty(frag.errors)
+
+              assert_raises(Nokogiri::SyntaxError) do
+                Nokogiri::XML.fragment(input, xml_strict)
+              end
+            end
+
+            it "takes a config block" do
+              default_config = nil
+              Nokogiri::XML.fragment(input) do |config|
+                default_config = config
+              end
+              refute(default_config.strict?)
+
+              assert_raises(Nokogiri::SyntaxError) do
+                Nokogiri::XML.fragment(input, &:norecover)
+              end
+            end
+          end
+
+          describe "XML::DocumentFragment.parse" do
+            it "has sane defaults" do
+              frag = Nokogiri::XML::DocumentFragment.parse(input)
+              assert_equal("<a>foo</a>", frag.to_html)
+              refute_empty(frag.errors)
+            end
+
+            it "accepts options" do
+              frag = Nokogiri::XML::DocumentFragment.parse(input, xml_default)
+              assert_equal("<a>foo</a>", frag.to_html)
+              refute_empty(frag.errors)
+
+              assert_raises(Nokogiri::SyntaxError) do
+                Nokogiri::XML::DocumentFragment.parse(input, xml_strict)
+              end
+            end
+
+            it "takes a config block" do
+              default_config = nil
+              Nokogiri::XML::DocumentFragment.parse(input) do |config|
+                default_config = config
+              end
+              refute(default_config.strict?)
+
+              assert_raises(Nokogiri::SyntaxError) do
+                Nokogiri::XML::DocumentFragment.parse(input, &:norecover)
+              end
+            end
+          end
+
+          describe "XML::DocumentFragment.new" do
+            describe "without a context node" do
+              it "has sane defaults" do
+                frag = Nokogiri::XML::DocumentFragment.new(Nokogiri::XML::Document.new, input)
+                assert_equal("<a>foo</a>", frag.to_html)
+                refute_empty(frag.errors)
+              end
+
+              it "accepts options" do
+                frag = Nokogiri::XML::DocumentFragment.new(Nokogiri::XML::Document.new, input, nil, xml_default)
+                assert_equal("<a>foo</a>", frag.to_html)
+                refute_empty(frag.errors)
+
+                assert_raises(Nokogiri::SyntaxError) do
+                  Nokogiri::XML::DocumentFragment.new(Nokogiri::XML::Document.new, input, nil, xml_strict)
+                end
+              end
+
+              it "takes a config block" do
+                default_config = nil
+                Nokogiri::XML::DocumentFragment.new(Nokogiri::XML::Document.new, input) do |config|
+                  default_config = config
+                end
+                refute(default_config.strict?)
+
+                assert_raises(Nokogiri::SyntaxError) do
+                  Nokogiri::XML::DocumentFragment.new(Nokogiri::XML::Document.new, input, &:norecover)
+                end
+              end
+            end
+
+            describe "with a context node" do
+              let(:document) { Nokogiri::XML::Document.parse("<context></context>") }
+              let(:context_node) { document.at_css("context") }
+
+              it "has sane defaults" do
+                frag = Nokogiri::XML::DocumentFragment.new(document, input, context_node)
+                assert_equal("<a>foo</a>", frag.to_html)
+                refute_empty(frag.errors)
+              end
+
+              it "accepts options" do
+                frag = Nokogiri::XML::DocumentFragment.new(document, input, context_node, xml_default)
+                assert_equal("<a>foo</a>", frag.to_html)
+                refute_empty(frag.errors)
+
+                assert_raises(Nokogiri::SyntaxError) do
+                  Nokogiri::XML::DocumentFragment.new(document, input, context_node, xml_strict)
+                end
+              end
+
+              it "takes a config block" do
+                default_config = nil
+                Nokogiri::XML::DocumentFragment.new(document, input, context_node) do |config|
+                  default_config = config
+                end
+                refute(default_config.strict?)
+
+                assert_raises(Nokogiri::SyntaxError) do
+                  Nokogiri::XML::DocumentFragment.new(document, input, context_node, &:norecover)
+                end
+              end
+            end
+          end
+        end
+
         describe "subclassing" do
           let(:klass) do
             Class.new(Nokogiri::XML::DocumentFragment) do
