@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+# frozen_string_literal: true
+
 require "helper"
 
 module Nokogiri
@@ -13,13 +15,13 @@ module Nokogiri
       def test_io_non_string
         io = NonStringIO.new
         reader = Nokogiri::XML::Reader(io)
-        assert_equal io, reader.source
+        assert_equal(io, reader.source)
       end
 
       def test_from_io_sets_io_as_source
-        io = File.open SNUGGLES_FILE
+        io = File.open(SNUGGLES_FILE)
         reader = Nokogiri::XML::Reader.from_io(io)
-        assert_equal io, reader.source
+        assert_equal(io, reader.source)
       end
 
       def test_empty_element?
@@ -32,7 +34,7 @@ module Nokogiri
             node.empty_element?
           end
         end
-        assert_equal [false, false, nil, nil, true, nil], results
+        assert_equal([false, false, nil, nil, true, nil], results)
       end
 
       def test_self_closing?
@@ -45,16 +47,16 @@ module Nokogiri
             node.self_closing?
           end
         end
-        assert_equal [false, false, nil, nil, true, nil], results
+        assert_equal([false, false, nil, nil, true, nil], results)
       end
 
       # Issue #831
       # Make sure that the reader doesn't block reading the entire input
       def test_reader_blocking
-        rd, wr = IO.pipe()
+        rd, wr = IO.pipe
         node_out = nil
         t = Thread.start do
-          reader = Nokogiri::XML::Reader(rd, 'UTF-8')
+          reader = Nokogiri::XML::Reader(rd, "UTF-8")
           reader.each do |node|
             node_out = node
             break
@@ -66,12 +68,12 @@ module Nokogiri
           wr.puts "<foo>"
           wr.puts "<bar/>" * 10000
           wr.flush
-        rescue Errno::EPIPE
+        rescue Errno::EPIPE # rubocop:disable Lint/SuppressedException
         end
         res = t.join(1) # give the thread a moment to finish
         wr.close
-        refute_nil node_out, "Didn't read any nodes, exclude the trivial case"
-        refute_nil res, "Reader blocks trying to read the entire stream"
+        refute_nil(node_out, "Didn't read any nodes, exclude the trivial case")
+        refute_nil(res, "Reader blocks trying to read the entire stream")
       end
 
       def test_reader_takes_block
@@ -80,34 +82,34 @@ module Nokogiri
           options = cfg
           options.nonet.nowarning.dtdattr
         end
-        assert options.nonet?
-        assert options.nowarning?
-        assert options.dtdattr?
+        assert(options.nonet?)
+        assert(options.nowarning?)
+        assert(options.dtdattr?)
       end
 
       def test_nil_raises
-        assert_raises(ArgumentError) {
+        assert_raises(ArgumentError) do
           Nokogiri::XML::Reader.from_memory(nil)
-        }
-        assert_raises(ArgumentError) {
+        end
+        assert_raises(ArgumentError) do
           Nokogiri::XML::Reader.from_io(nil)
-        }
+        end
       end
 
       def test_from_io
-        io = File.open SNUGGLES_FILE
+        io = File.open(SNUGGLES_FILE)
         reader = Nokogiri::XML::Reader.from_io(io)
-        assert_equal false, reader.default?
-        assert_equal [false, false, false, false, false, false, false],
-          reader.map(&:default?)
+        refute(reader.default?)
+        assert_equal([false, false, false, false, false, false, false],
+          reader.map(&:default?))
       end
 
       def test_io
-        io = File.open SNUGGLES_FILE
+        io = File.open(SNUGGLES_FILE)
         reader = Nokogiri::XML::Reader(io)
-        assert_equal false, reader.default?
-        assert_equal [false, false, false, false, false, false, false],
-          reader.map(&:default?)
+        refute(reader.default?)
+        assert_equal([false, false, false, false, false, false, false],
+          reader.map(&:default?))
       end
 
       def test_string_io
@@ -117,35 +119,34 @@ module Nokogiri
         </x>
         eoxml
         reader = Nokogiri::XML::Reader(io)
-        assert_equal false, reader.default?
-        assert_equal [false, false, false, false, false, false, false],
-          reader.map(&:default?)
+        refute(reader.default?)
+        assert_equal([false, false, false, false, false, false, false],
+          reader.map(&:default?))
       end
 
       class ReallyBadIO
         def read(size)
-          'a' * size ** 10
+          "a" * size**10
         end
       end
 
       class ReallyBadIO4Java
-        def read(size=1)
-          'a' * size ** 10
+        def read(size = 1)
+          "a" * size**10
         end
       end
 
       def test_io_that_reads_too_much
-        if Nokogiri.jruby?
-          io = ReallyBadIO4Java.new
-          Nokogiri::XML::Reader(io)
+        io = if Nokogiri.jruby?
+          ReallyBadIO4Java.new
         else
-          io = ReallyBadIO.new
-          Nokogiri::XML::Reader(io)
+          ReallyBadIO.new
         end
+        Nokogiri::XML::Reader(io)
       end
 
       def test_in_memory
-        assert Nokogiri::XML::Reader(<<-eoxml)
+        assert(Nokogiri::XML::Reader(<<-eoxml))
         <x xmlns:tenderlove='http://tenderlovemaking.com/'>
           <tenderlove:foo awesome='true'>snuggles!</tenderlove:foo>
         </x>
@@ -159,7 +160,7 @@ module Nokogiri
         </x>
         eoxml
         reader = Nokogiri::XML::Reader(xml)
-        assert_equal xml, reader.source
+        assert_equal(xml, reader.source)
       end
 
       def test_default?
@@ -168,9 +169,9 @@ module Nokogiri
           <tenderlove:foo awesome='true'>snuggles!</tenderlove:foo>
         </x>
         eoxml
-        assert_equal false, reader.default?
-        assert_equal [false, false, false, false, false, false, false],
-          reader.map(&:default?)
+        refute(reader.default?)
+        assert_equal([false, false, false, false, false, false, false],
+          reader.map(&:default?))
       end
 
       def test_value?
@@ -179,9 +180,9 @@ module Nokogiri
           <tenderlove:foo awesome='true'>snuggles!</tenderlove:foo>
         </x>
         eoxml
-        assert_equal false, reader.value?
-        assert_equal [false, true, false, true, false, true, false],
-          reader.map(&:value?)
+        refute(reader.value?)
+        assert_equal([false, true, false, true, false, true, false],
+          reader.map(&:value?))
       end
 
       def test_read_error_document
@@ -194,26 +195,26 @@ module Nokogiri
         assert_raises(Nokogiri::XML::SyntaxError) do
           reader.each { |node| }
         end
-        assert 1, reader.errors.length
+        assert_equal(1, reader.errors.length)
       end
 
       def test_errors_is_an_array
-        reader = Nokogiri::XML::Reader(StringIO.new('&bogus;'))
-        assert_raises(SyntaxError) {
+        reader = Nokogiri::XML::Reader(StringIO.new("&bogus;"))
+        assert_raises(SyntaxError) do
           reader.read
-        }
-        assert_equal [SyntaxError], reader.errors.map(&:class)
+        end
+        assert_equal([SyntaxError], reader.errors.map(&:class))
       end
 
       def test_pushing_to_non_array_raises_TypeError
         skip_unless_libxml2("TODO: JRuby ext does not internally call `errors`")
-        reader = Nokogiri::XML::Reader(StringIO.new('&bogus;'))
+        reader = Nokogiri::XML::Reader(StringIO.new("&bogus;"))
         def reader.errors
           1
         end
-        assert_raises(TypeError) {
+        assert_raises(TypeError) do
           reader.read
-        }
+        end
       end
 
       def test_attributes?
@@ -222,9 +223,9 @@ module Nokogiri
           <tenderlove:foo awesome='true'>snuggles!</tenderlove:foo>
         </x>
         eoxml
-        assert_equal false, reader.attributes?
-        assert_equal [true, false, true, false, true, false, true],
-          reader.map(&:attributes?)
+        refute(reader.attributes?)
+        assert_equal([true, false, true, false, true, false, true],
+          reader.map(&:attributes?))
       end
 
       def test_attributes
@@ -235,13 +236,13 @@ module Nokogiri
           <tenderlove:foo awesome='true'>snuggles!</tenderlove:foo>
         </x>
         eoxml
-        assert_equal({}, reader.attributes)
-        assert_equal [{'xmlns:tenderlove'=>'http://tenderlovemaking.com/',
-                       'xmlns'=>'http://mothership.connection.com/'},
-                      {}, {"awesome"=>"true"}, {}, {"awesome"=>"true"}, {},
-                      {'xmlns:tenderlove'=>'http://tenderlovemaking.com/',
-                       'xmlns'=>'http://mothership.connection.com/'}],
-          reader.map(&:attributes)
+        assert_empty(reader.attributes)
+        assert_equal([{ "xmlns:tenderlove" => "http://tenderlovemaking.com/",
+                        "xmlns" => "http://mothership.connection.com/", },
+                      {}, { "awesome" => "true" }, {}, { "awesome" => "true" }, {},
+                      { "xmlns:tenderlove" => "http://tenderlovemaking.com/",
+                        "xmlns" => "http://mothership.connection.com/", },],
+          reader.map(&:attributes))
       end
 
       def test_attribute_roundtrip
@@ -254,7 +255,7 @@ module Nokogiri
         eoxml
         reader.each do |node|
           node.attributes.each do |key, value|
-            assert_equal value, node.attribute(key)
+            assert_equal(value, node.attribute(key))
           end
         end
       end
@@ -265,10 +266,10 @@ module Nokogiri
           <tenderlove:foo awesome='true'>snuggles!</tenderlove:foo>
         </x>
         eoxml
-        assert_nil reader.attribute_at(nil)
-        assert_nil reader.attribute_at(0)
-        assert_equal ['http://tenderlovemaking.com/', nil, 'true', nil, 'true', nil, 'http://tenderlovemaking.com/'],
-          reader.map { |x| x.attribute_at(0) }
+        assert_nil(reader.attribute_at(nil))
+        assert_nil(reader.attribute_at(0))
+        assert_equal(["http://tenderlovemaking.com/", nil, "true", nil, "true", nil, "http://tenderlovemaking.com/"],
+          reader.map { |x| x.attribute_at(0) })
       end
 
       def test_attribute
@@ -277,10 +278,10 @@ module Nokogiri
           <tenderlove:foo awesome='true'>snuggles!</tenderlove:foo>
         </x>
         eoxml
-        assert_nil reader.attribute(nil)
-        assert_nil reader.attribute('awesome')
-        assert_equal [nil, nil, 'true', nil, 'true', nil, nil],
-          reader.map { |x| x.attribute('awesome') }
+        assert_nil(reader.attribute(nil))
+        assert_nil(reader.attribute("awesome"))
+        assert_equal([nil, nil, "true", nil, "true", nil, nil],
+          reader.map { |x| x.attribute("awesome") })
       end
 
       def test_attribute_length
@@ -289,8 +290,8 @@ module Nokogiri
           <tenderlove:foo awesome='true'>snuggles!</tenderlove:foo>
         </x>
         eoxml
-        assert_equal 0, reader.attribute_count
-        assert_equal [1, 0, 1, 0, 0, 0, 0], reader.map(&:attribute_count)
+        assert_equal(0, reader.attribute_count)
+        assert_equal([1, 0, 1, 0, 0, 0, 0], reader.map(&:attribute_count))
       end
 
       def test_depth
@@ -299,8 +300,8 @@ module Nokogiri
           <tenderlove:foo>snuggles!</tenderlove:foo>
         </x>
         eoxml
-        assert_equal 0, reader.depth
-        assert_equal [0, 1, 1, 2, 1, 1, 0], reader.map(&:depth)
+        assert_equal(0, reader.depth)
+        assert_equal([0, 1, 1, 2, 1, 1, 0], reader.map(&:depth))
       end
 
       def test_encoding
@@ -310,8 +311,8 @@ module Nokogiri
           <p xml:lang="ja">日本語が上手です</p>
         </awesome>
         eoxml
-        reader = Nokogiri::XML::Reader.from_memory(string, nil, 'UTF-8')
-        assert_equal ['UTF-8'], reader.map(&:encoding).uniq
+        reader = Nokogiri::XML::Reader.from_memory(string, nil, "UTF-8")
+        assert_equal(["UTF-8"], reader.map(&:encoding).uniq)
       end
 
       def test_xml_version
@@ -320,8 +321,8 @@ module Nokogiri
           <tenderlove:foo>snuggles!</tenderlove:foo>
         </x>
         eoxml
-        assert_nil reader.xml_version
-        assert_equal ['1.0'], reader.map(&:xml_version).uniq
+        assert_nil(reader.xml_version)
+        assert_equal(["1.0"], reader.map(&:xml_version).uniq)
       end
 
       def test_lang
@@ -331,9 +332,9 @@ module Nokogiri
           <p xml:lang="ja">日本語が上手です</p>
         </awesome>
         eoxml
-        assert_nil reader.lang
-        assert_equal [nil, nil, "en", "en", "en", nil, "ja", "ja", "ja", nil, nil],
-          reader.map(&:lang)
+        assert_nil(reader.lang)
+        assert_equal([nil, nil, "en", "en", "en", nil, "ja", "ja", "ja", nil, nil],
+          reader.map(&:lang))
       end
 
       def test_value
@@ -342,9 +343,9 @@ module Nokogiri
           <tenderlove:foo>snuggles!</tenderlove:foo>
         </x>
         eoxml
-        assert_nil reader.value
-        assert_equal [nil, "\n          ", nil, "snuggles!", nil, "\n        ", nil],
-          reader.map(&:value)
+        assert_nil(reader.value)
+        assert_equal([nil, "\n          ", nil, "snuggles!", nil, "\n        ", nil],
+          reader.map(&:value))
       end
 
       def test_prefix
@@ -353,9 +354,9 @@ module Nokogiri
           <edi:foo>hello</edi:foo>
         </x>
         eoxml
-        assert_nil reader.prefix
-        assert_equal [nil, nil, "edi", nil, "edi", nil, nil],
-          reader.map(&:prefix)
+        assert_nil(reader.prefix)
+        assert_equal([nil, nil, "edi", nil, "edi", nil, nil],
+          reader.map(&:prefix))
       end
 
       def test_node_type
@@ -364,8 +365,8 @@ module Nokogiri
           <y>hello</y>
         </x>
         eoxml
-        assert_equal 0, reader.node_type
-        assert_equal [1, 14, 1, 3, 15, 14, 15], reader.map(&:node_type)
+        assert_equal(0, reader.node_type)
+        assert_equal([1, 14, 1, 3, 15, 14, 15], reader.map(&:node_type))
       end
 
       def test_inner_xml
@@ -374,7 +375,7 @@ module Nokogiri
 
         reader.read
 
-        assert_equal "<y>hello</y>", reader.inner_xml
+        assert_equal("<y>hello</y>", reader.inner_xml)
       end
 
       def test_outer_xml
@@ -384,7 +385,7 @@ module Nokogiri
         xml = []
         reader.map { |node| xml << node.outer_xml }
 
-        assert_equal str, xml
+        assert_equal(str, xml)
       end
 
       def test_outer_xml_with_empty_nodes
@@ -394,12 +395,12 @@ module Nokogiri
         xml = []
         reader.map { |node| xml << node.outer_xml }
 
-        assert_equal str, xml
+        assert_equal(str, xml)
       end
 
       def test_state
-        reader = Nokogiri::XML::Reader.from_memory('<foo>bar</bar>')
-        assert reader.state
+        reader = Nokogiri::XML::Reader.from_memory("<foo>bar</bar>")
+        assert(reader.state)
       end
 
       def test_ns_uri
@@ -408,15 +409,15 @@ module Nokogiri
           <edi:foo>hello</edi:foo>
         </x>
         eoxml
-        assert_nil reader.namespace_uri
+        assert_nil(reader.namespace_uri)
         assert_equal([nil,
                       nil,
                       "http://ecommerce.example.org/schema",
                       nil,
                       "http://ecommerce.example.org/schema",
                       nil,
-                      nil],
-                      reader.map(&:namespace_uri))
+                      nil,],
+          reader.map(&:namespace_uri))
       end
 
       def test_reader_node_attributes_keep_a_reference_to_the_reader
@@ -451,13 +452,13 @@ module Nokogiri
         attr_ns = []
         while reader.read
           if reader.node_type == Nokogiri::XML::Node::ELEMENT_NODE
-            reader.attribute_nodes.each {|attr| attr_ns << (attr.namespace.nil? ? nil : attr.namespace.prefix) }
+            reader.attribute_nodes.each { |attr| attr_ns << (attr.namespace.nil? ? nil : attr.namespace.prefix) }
           end
         end
-        assert_equal(['commons',
-                      'edi',
-                      nil],
-                     attr_ns)
+        assert_equal(["commons",
+                      "edi",
+                      nil,],
+          attr_ns)
       end
 
       def test_local_name
@@ -466,9 +467,9 @@ module Nokogiri
           <edi:foo>hello</edi:foo>
         </x>
         eoxml
-        assert_nil reader.local_name
+        assert_nil(reader.local_name)
         assert_equal(["x", "#text", "foo", "#text", "foo", "#text", "x"],
-                     reader.map(&:local_name))
+          reader.map(&:local_name))
       end
 
       def test_name
@@ -477,9 +478,9 @@ module Nokogiri
           <edi:foo>hello</edi:foo>
         </x>
         eoxml
-        assert_nil reader.name
+        assert_nil(reader.name)
         assert_equal(["x", "#text", "edi:foo", "#text", "edi:foo", "#text", "x"],
-                     reader.map(&:name))
+          reader.map(&:name))
       end
 
       def test_base_uri
@@ -493,7 +494,7 @@ module Nokogiri
           </x>
         eoxml
 
-        assert_nil reader.base_uri
+        assert_nil(reader.base_uri)
         assert_equal(["http://base.example.org/base/",
                       "http://base.example.org/base/",
                       "http://base.example.org/base/",
@@ -506,8 +507,8 @@ module Nokogiri
                       "http://base.example.org/base/relative",
                       "http://base.example.org/base/relative",
                       "http://base.example.org/base/",
-                      "http://base.example.org/base/"],
-                      reader.map(&:base_uri))
+                      "http://base.example.org/base/",],
+          reader.map(&:base_uri))
       end
 
       def test_xlink_href_without_base_uri
@@ -519,10 +520,9 @@ module Nokogiri
         eoxml
 
         reader.each do |node|
-          if node.node_type == Nokogiri::XML::Reader::TYPE_ELEMENT
-            if node.name == 'link'
-              assert_nil node.base_uri
-            end
+          next unless node.node_type == Nokogiri::XML::Reader::TYPE_ELEMENT
+          if node.name == "link"
+            assert_nil(node.base_uri)
           end
         end
       end
@@ -538,19 +538,19 @@ module Nokogiri
 
         reader.each do |node|
           if node.node_type == Nokogiri::XML::Reader::TYPE_ELEMENT
-            assert_equal node.base_uri, "http://base.example.org/base/"
+            assert_equal("http://base.example.org/base/", node.base_uri)
           end
         end
       end
 
       def test_read_from_memory
         called = false
-        reader = Nokogiri::XML::Reader.from_memory('<foo>bar</foo>')
+        reader = Nokogiri::XML::Reader.from_memory("<foo>bar</foo>")
         reader.each do |node|
           called = true
-          assert node
+          assert(node)
         end
-        assert called
+        assert(called)
       end
 
       def test_large_document_smoke_test
@@ -561,9 +561,7 @@ module Nokogiri
         xml << "</elements>"
         xml = xml.join("\n")
 
-        Nokogiri::XML::Reader.from_memory(xml).each do |e|
-          e.attributes
-        end
+        Nokogiri::XML::Reader.from_memory(xml).each(&:attributes)
       end
 
       def test_correct_outer_xml_inclusion
@@ -587,15 +585,15 @@ module Nokogiri
         has_child2 = []
 
         xml.each do |node|
-          if node.node_type == Nokogiri::XML::Reader::TYPE_ELEMENT and node.name == "child"
+          if (node.node_type == Nokogiri::XML::Reader::TYPE_ELEMENT) && (node.name == "child")
             nodelengths << node.outer_xml.length
-            has_child2 << !!(node.outer_xml =~ /child-2/)
+            has_child2 << !!node.outer_xml.include?("child-2")
           end
         end
 
         assert_equal(nodelengths[0], nodelengths[1])
         assert(has_child2[1])
-        assert(!has_child2[0])
+        refute(has_child2[0])
       end
 
       def test_correct_inner_xml_inclusion
@@ -619,23 +617,23 @@ module Nokogiri
         has_child2 = []
 
         xml.each do |node|
-          if node.node_type == Nokogiri::XML::Reader::TYPE_ELEMENT and node.name == "child"
+          if (node.node_type == Nokogiri::XML::Reader::TYPE_ELEMENT) && (node.name == "child")
             nodelengths << node.inner_xml.length
-            has_child2 << !!(node.inner_xml =~ /child-2/)
+            has_child2 << !!node.inner_xml.include?("child-2")
           end
         end
 
         assert_equal(nodelengths[0], nodelengths[1])
         assert(has_child2[1])
-        assert(!has_child2[0])
+        refute(has_child2[0])
       end
 
       def test_nonexistent_attribute
-        require 'nokogiri'
+        require "nokogiri"
         reader = Nokogiri::XML::Reader("<root xmlns='bob'><el attr='fred' /></root>")
         reader.read # root
         reader.read # el
-        assert_nil reader.attribute('other')
+        assert_nil(reader.attribute("other"))
       end
     end
   end
